<?php
namespace Teknisa\OPL\Controllers;

use \Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DTO\Response\Error;
use \Zeedhi\Framework\DTO\Request\Row;
use \Zeedhi\Framework\DTO\Response\Message;
use \Zeedhi\Framework\DTO\Response;
use \Zeedhi\Framework\DataSource\DataSet;
use \Zeedhi\Framework\DataSource;
use Exception;
use \Teknisa\OPL\Services\Dfs48000SaidaDoOperadorLogisticoService;
    
class Dfs48000SaidaDoOperadorLogisticoController extends \Teknisa\GER\Controllers\TeknisaCrud {
    
    protected $crudService;
    
    public function __construct($crudService, $parameterBag, Dfs48000SaidaDoOperadorLogisticoService $service) {
        $this->crudService  = $crudService;
        $this->service      = $service;
        $this->parameterBag = $parameterBag;
    }
    
    public function getDtProcessaOpl(Row $request, Response $response) {
        try {
            $params = $request->getRow();
        
            $result = $this->service->getDtProcessaOpl($params);
            $dtprocessa = $this->service->getDtProcessaAtual($params);
            
            $result[] = isset($dtprocessa) ? $dtprocessa[0] : null;
            
            $response->addDataSet(new DataSet('res', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function getLogErro(Row $request, Response $response) {
        try {
            $params = $request->getRow();
        
            $result = $this->service->getLogErro($params);
            
            $response->addDataSet(new DataSet('res', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function validaItensPedido(Row $request, Response $response) {
        try {
            $rows = $request->getRow();
            $dados = $rows['DADOSGERACAO'];
            $pedidos = $rows['NFS'];
            $retornos = array();
            $pedComErro = array();
            $pedSemErro = array();
            $pedidosParaSaida = array();
            $retornoSaida;
            
            $dtprocessa = $this->service->getDtProcessaAtual($dados);
            $stwebservice = $this->service->getStWebService($dados);
            
            if(!empty($stwebservice)) {
                $dados['WEBSERVICE'] = 'S';
            } else {
                $dados['WEBSERVICE'] = 'N';
            }
            
            $dados['DTPROC'] = $dtprocessa[0]['DTPROCESSA'];
            
            foreach($pedidos as $ped) {
                $result = $this->service->validaItensPedido($ped, $dados);
                
                if(!empty($result)) {
                    foreach($result as $res) {
                        if(isset($res['LISTAERRO']) && $res['LISTAERRO'] != NULL) {
                            $strErro = '';
                            $codErros = explode('_', $res['LISTAERRO']);
                            $codErros = array_filter($codErros, static function($e) {
                                return $e != "";
                            });
                            
                            foreach($codErros as $err) {
                                if($strErro != '')
                                    $strErro .= "\n";
                                    
                                switch($err) {
                                    case 'PRODINATIVO':
                                        $strErro .= "Produto Inativo para o OL.";
                                        break;
                                    case 'ERROVLR':
                                        $strErro .= "Produto com Custo menor ou igual a zero.";
                                        break;
                                    case 'ERRORES':
                                        $strErro .= "Produto sem Reserva.";
                                        break;
                                    case 'ERROQTD':
                                        $strErro .= "Quantidade atendida pelo OL deve ser informada.";
                                        break;
                                    case 'ERRORELAC':
                                        $strErro .= "Produto sem relacionamento com produto do OL.";
                                        break;
                                    case 'ERROEST':
                                        $strErro .= "Sem quantidade disponível no estoque do OL.";
                                        break;
                                    case 'ERROCX':
                                        $strErro .= "Produto caixa inativo.";
                                        break;
                                }
                            }
                            
                            $res['NMERRO'] = $strErro;
                            
                            $retornos[] = $res;
                            
                            if(!in_array($res['NRAUTOFORN'], $pedComErro)) {
                                $pedComErro[] = $res['NRAUTOFORN'];
                            }
                        } else {
                            $pedSemErro[] = $res['NRAUTOFORN'];
                        }
                    }
                    
                    if(count($pedComErro) > 0) {
                        foreach($pedidos as $ped) {
                            if(!in_array($ped['NRAUTOFORN'], $pedComErro)) {
                                if(!in_array($ped['NRAUTOFORN'], $pedSemErro)) {
                                    $pedSemErro[] = $ped['NRAUTOFORN'];
                                }
                            }
                        }
                    }
                }
            }
            
            if(count($pedSemErro)) {
                foreach($pedSemErro as $pse) {
                    foreach($pedidos as $ped) {
                        if($ped['NRAUTOFORN'] == $pse) {
                            $pedidosParaSaida[] = $ped;
                        }
                    }
                }
            }
            
            if(count($pedidosParaSaida) > 0) {
                 $retornoSaidaEntrada = $this->service->gerarSaida($pedidosParaSaida, $dados);
            } else {
                $retornoSaidaEntrada = array(
                    'NFS_ERRO'    => array(),
                    'NFS_SUCESSO' => array(),
                    'NFE_ERRO'    => array(),
                    'NFE_SUCESSO' => array()
                );
            }
            
            $response->addDataSet(new DataSet('saidaEntrada', $retornoSaidaEntrada));
            $response->addDataSet(new DataSet('pedErros', $retornos));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function procedureIncluiReservaOL(Row $request, Response $response) {
        try {
            $params = $request->getRow();
      
            $result = $this->service->procedureIncluiReservaOL($params);
            
            $response->addDataSet(new DataSet('result', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
     public function validaTipoOp(Row $request, Response $response) {
        try {
            $params = $request->getRow();
      
            $result = $this->service->validaTipoOp($params);
            
            $response->addDataSet(new DataSet('result', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function importaAjustesPedidoOL(Row $request, Response $response) {
        try {
            $rows = $request->getRow();
            $filtro = $rows['FILTRO'];
            $itens = $rows['ITENS'];
            $itemNaoImportado = array();
            
            $parasupri = $this->service->getParamSupri($filtro['P_FILOPELOG'])[0];
            
            foreach($itens as $item) {
                $item['QTDE_PRODUTO'] = $item['QTDE_PRODUTO'] == '' ? 0 : intval($item['QTDE_PRODUTO']);
                $item['PESO_LIQ_ITEM'] = (intval($item['PESO_LIQ_ITEM']) / 1000);
                $item['QTDE_VOLUMES'] = $item['QTDE_VOLUMES'] == '' ? 0 : intval($item['QTDE_VOLUMES']);
                $item['VLR_UNITARIO'] = $item['VLR_UNITARIO'] == '' ? 0 : (floatval($item['VLR_UNITARIO']) / 1000);
                
               if($parasupri['IDUTILCONSSOLIOL'] == 'S') {
                    $adqPedidoExol1 = $this->service->adqPedidoExol1($filtro['P_FILOPELOG'], $item['NUM_PEDIDO']);
                    if(!empty($adqPedidoExol1)) {
                        $adqVariacao = $this->service->adqVariacao($item['COD_PRODUTO']);
                        
                        if(!empty($adqVariacao)) {
                            $stVariacao = $adqVariacao[0]['VARIACAO'] != '1' ? 'YY' : 'CX';
                            
                            if($item['QTDE_PRODUTO'] == 0 || $item['PESO_LIQ_ITEM'] == 0) {
                                $this->service->acmUpdQuantZero($adqPedidoExol1[0], $adqVariacao[0]);
                                
                                $this->service->acmDelReservaimporta($adqPedidoExol1[0], $adqVariacao[0]);
                            } else {
                                $adqQuantAlterada = $this->service->adqQuantAlterada($adqPedidoExol1[0], $adqVariacao[0]);
                                
                                if(!empty($adqQuantAlterada)) {
                                    $this->service->acmUpdItPexol($adqPedidoExol1[0], $adqVariacao[0], $item, $stVariacao);
                                    $this->service->acmUpdReserva($adqPedidoExol1[0], $adqVariacao[0], $item);
                                }
                            }
                        } else {
                            $itemNaoImportado[] = $item;
                        }
                    } else {
                        $itemNaoImportado[] = $item;
                    }
                } else {
                    if($item['COD_PRODUTO'] != '') {
                        $adqItemAutF = $this->service->adqItemAutF($item);
                        
                        if(!empty($adqItemAutF)) {
                            if($item['QTDE_PRODUTO'] > 0) {
                                $this->service->acmUpdItemAutF($adqItemAutF[0], $item);
                            } else {
                                $this->service->acmUpdItemAutF1($adqItemAutF[0], $item);
                            }
                        } else {
                            $itemNaoImportado[] = $item;
                        }
                    } else {
                        $itemNaoImportado[] = $item;
                    }
                }
            }
            
            $response->addDataSet(new DataSet('itens_erros', $itemNaoImportado));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
