<?php
namespace Folha\Logic\ESocial\Exceptions;

class PreValidacaoException extends \Geral\Logic\Exception
{
    private $messageName;

    public function __construct($messageName) {
        $this->messageName = $messageName;
    }

    /**
     * Retorna o nome da mensagem.
     *
     * @abstract
     * @return string
     */
    public function getMessageName()
    {
        return $this->messageName;
    }

    /**
     * Retorna a mensagem para o código passado.
     *
     * Obs: Os códigos das mensagens estão organizados em ordem alfabética para localização.
     *
     * @abstract
     * @return string
     */
    public static function retornaMensagem($codigo)
    {
        switch($codigo)
        {
            case 'AliqRat_N_Info':
                return "Alíquota RAT deve ser informada.";
                break;
            case 'BaseCP_N_Info':
                return "Base de cálculo da contribuição previdenciária deve ser informada.";
                break;
            case 'BaseFGTS_N_Info':
                return "Base de cálculo do FGTS deve ser informada.";
                break;
            case 'BaseIRRF_N_Info':
                return "Base de cálculo do IRRF deve ser informada.";
                break;
            case 'CBO_N_Info':
                return "CBO deve ser informado.";
                break;
            case 'ClassTrib_Invalid_TpInsc':
                return "Classificaçao Tributária inválida para o tipo de inscrição.";
                break;
            case 'ClassTrib_N_Info':
                return "Classificaçao Tributária deve ser informada.";
                break;
            case 'CNAE_N_Info':
                return "Cnae Preponderante deve ser informado.";
                break;
            case 'CNPJ_Benef_Invalid':
                return "CNPJ do Beneficiário inválido.";
                break;
            case 'CNPJ_Contrib_Invalid':
                return "CNPJ do contribuinte inválido.";
                break;
            case 'CNPJ_Estab_Invalid':
                return "CNPJ do estabelecimento inválido.";
                break;
            case 'CodAgCausad_N_Info':
                return "Código do agente causador deve ser informado.";
                break;
            case 'CodCarg_N_Info':
                return "Código do cargo deve ser informado.";
                break;
            case 'CodCateg_N_Info':
                return "Código da categoria do trabalhador deve ser informado.";
                break;
            case 'CodFuncao_N_Info':
                return "Código da função deve ser informado.";
                break;
            case 'CodHorContr_N_Info':
                return "Código do horário contratual deve ser informado.";
                break;
            case 'CodIncidCp_N_Info':
                return "Código de incidência para Previdência Social deve ser informado.";
                break;
            case 'CodIncidFGTS_N_Info':
                return "Código de incidência para FGTS deve ser informado.";
                break;
            case 'CodIncidIRRF_N_Info':
                return "Código de incidência para IRRF deve ser informado.";
                break;
            case 'CodIncidSind_N_Info':
                return "Código de incidência para Contribuição Sindical deve ser informado.";
                break;
            case 'CodLota_N_Info':
                return "Código da lotação deve ser informado.";
                break;
            case 'CodMotAfast_N_Info':
                return "Código do motivo do afastamento deve ser informado.";
                break;
            case 'CodMotEstabil_N_Info':
                return "Código do motivo da estabilidade deve ser informado.";
                break;
            case 'CodPartAting_N_Info':
                return "Código da parte atingida deve ser informado.";
                break;
            case 'CodRend_N_Info':
                return "Código do rendimento deve ser informado.";
                break;
            case 'CodRubr_N_Info':
                return "Código da rubrica deve ser informado.";
                break;
            case 'CodTerc_N_Info':
                return "Código de terceiros deve ser informado.";
                break;
            case 'CPF_Benef_Invalid':
                return "CPF do benficiário inválido.";
                break;
            case 'CPF_Contat_N_Info':
                return "CPF do contato deve ser informado.";
                break;
            case 'CPF_Contrib_Invalid':
                return "CPF do contribuinte inválido.";
                break;
            case 'CPF_Trab_Invalid':
                return "CPF do trabalhador inválido.";
                break;
            case 'CPF_Trab_N_Info':
                return "CPF do trabalhador deve ser informado.";
                break;
            case 'DescCarg_N_Info':
                return "Descrição do cargo deve ser informada.";
                break;
            case 'DescFuncao_N_Info':
                return "Descrição da função deve ser informada.";
                break;
            case 'DescLota_N_Info':
                return "Descrição da lotação deve ser informada.";
                break;
            case 'DesconCP_N_Info':
                return "Valor descontado da contribuição previdenciária deve ser informada.";
                break;
            case 'DescRubr_N_Info':
                return "Descrição da rubrica deve ser informado.";
                break;
            case 'DtAcidente_N_Info':
                return "Data do acidente deve ser informada.";
                break;
            case 'DtAdmis_N_Info':
                return "Data de admissão deve ser informada.";
                break;
            case 'DtAfast_N_Info':
                return "Data do afastamento deve ser informada.";
                break;
            case 'DtAlter_N_Info':
                return "Data de alteração deve ser informada.";
                break;
            case 'DtAviso_N_Info':
                return "Data do aviso prévio deve ser informada.";
                break;
            case 'DtDeslig_N_Info':
                return "Data do desligamento deve ser informada.";
                break;
            case 'DtIni_Valid_N_Info':
                return "Data de início da validade deve ser informada.";
                break;
            case 'DtIniEstabil_N_Info':
                return "Data de início da estabilidade deve ser informada.";
                break;
            case 'DtFimEstabil_N_Info':
                return "Data de término da estabilidade deve ser informada.";
                break;
            case 'DtNasc_N_Info':
                return "Data de nascimento deve ser informada.";
                break;
            case 'DtPrevDesl_N_Info':
                return "Data de previsão do desligamento deve ser informada.";
                break;
            case 'DtRetorno_N_Info':
                return "Data de retorno deve ser informada.";
                break;
            case 'DtTermAPI_N_Info':
                return "Data de término do API deve ser informada.";
                break;
            case 'DurJornad_N_Info':
                return "Duração da jornada deve ser informada.";
                break;
            case 'EstCiv_N_Info':
                return "Estado civil deve ser informado.";
                break;
            case 'FAP_N_Info':
                return "Fator Acidentário de Prevenção(FAP) deve ser informado.";
                break;
            case 'FPAS_N_Info':
                return "FPAS deve ser informado.";
                break;
            case 'GrInstr_N_Info':
                return "Grau de instrução deve ser informado.";
                break;
            case 'HoraAcid_N_Info':
                return "Hora do acidente deve ser informada.";
                break;
            case 'HoraEntr_N_Info':
                return "Hora de entrada deve ser informada.";
                break;
            case 'HoraSaid_N_Info':
                return "Hora de saída deve ser informada.";
                break;
            case 'HrsTrabAntAci_N_Info':
                return "Quantidade de horas trabalhadas antes do acidente deve ser informada.";
                break;
            case 'IndAdmis_N_Info':
                return "Indicativo de admissão deve ser informado.";
                break;
            case 'IndCatObito_N_Info':
                return "Indicador se houve óbito deve ser informado.";
                break;
            case 'IndCatParc_N_Info':
                return "Indicador de CAT parcial deve ser informado.";
                break;
            case 'IndComunPolic_N_Info':
                return "Indicador se houve comunicação à polícia deve ser informado.";
                break;
            case 'IndCoop_Invalid_ClassTrib':
                return "Indicativo de Cooperativa inválido para classificação tributária.";
                break;
            case 'IndConst_Invalid':
                return "Indicativo de Construtora inválido.";
                break;
            case 'IndNIF_N_Info':
                return "Indicativo do número de identificação fiscal deve ser informado.";
                break;
            case 'IndPagAPI_N_Info':
                return "Indicativo de pagamento de Aviso Prévio Indenizado deve ser informado.";
                break;
            case 'IndPriEmpr_N_Info':
                return "Indicativo de primeiro emprego deve ser informado.";
                break;
            case 'IndProvDesc_N_Info':
                return "Indicativo de tipo de rubrica deve ser informado.";
                break;
            case 'Insc_Benef_N_Info':
                return "Inscrição do beneficiário deve ser informada.";
                break;
            case 'Insc_Contrib_N_Info':
                return "Inscrição do contribuinte deve ser informada.";
                break;
            case 'Insc_Estab_Invalid_TpLota':
                return "Inscrição do estabelecimento inválida para o tipo de lotação.";
                break;
            case 'Insc_Estab_N_Info':
                return "Inscrição do estabelecimento deve ser informada.";
                break;
            case 'Insc_LocTrab_N_Info':
                return "Inscrição do local de trabalho deve ser informada.";
                break;
            case 'Matric_N_Info':
                return "Matrícula deve ser informada.";
                break;
            case 'Motiv_Desli_N_Info':
                return "Motivo do desligamento deve ser informado.";
                break;
            case 'NatAtiv_N_Info':
                return "Natureza da atividade deve ser informada.";
                break;
            case 'NatRubr_N_Info':
                return "Natureza da rubrica deve ser informada.";
                break;
            case 'NIS_N_Info':
                return "NIS(PIS, PASEP ou NIT) deve ser informado.";
                break;
            case 'Nome_Benef_N_Info':
                return "Nome do beneficiário deve ser informado.";
                break;
            case 'Nome_Contat_N_Info':
                return "Nome do contato deve ser informado.";
                break;
            case 'Nome_Trab_N_Info':
                return "Nome do trabalhador deve ser informado.";
                break;
            case 'PaisBenef_N_Info':
                return "País do beneficiário deve ser informado.";
                break;
            case 'PaisNasc_N_Info':
                return "País de nascimento deve ser informado.";
                break;
            case 'PaisNacio_N_Info':
                return "País de nacionalidade deve ser informado.";
                break;
            case 'QtdDepSf_N_Info':
                return "Quantidade de dependentes para pagamento do salário família deve ser informado.";
                break;
            case 'QtdDepIRRF_N_Info':
                return "Quantidade de dependentes para dedução do IRRF deve ser informado.";
                break;
            case 'QtdRubr_N_Info':
                return "Quantidade da rubrica deve ser informada.";
                break;
            case 'Raca_N_Info':
                return "Raça/Cor deve ser informado(a).";
                break;
            case 'RazSoc_N_Info':
                return "Razão Social deve ser informada.";
                break;
            case 'RepDecTerc_N_Info':
                return "Indicador para repercussão no cálculo do DSR deve ser informado.";
                break;
            case 'RepDSR_N_Info':
                return "Indicador para repercussão no cálculo do 13º Salário deve ser informado.";
                break;
            case 'RepFerias_N_Info':
                return "Indicador para repercussão no cálculo das Férias deve ser informado.";
                break;
            case 'RepRescis_N_Info':
                return "Indicador para repercussão no cálculo da Rescisão deve ser informado.";
                break;
            case 'Sexo_N_Info':
                return "Sexo deve ser informado.";
                break;
            case 'TpAcidente_N_Info':
                return "Tipo de acidente deve ser informado.";
                break;
            case 'TpAdmis_N_Info':
                return "Tipo de admissão deve ser informado.";
                break;
            case 'TpCat_N_Info':
                return "Tipo de CAT deve ser informado.";
                break;
            case 'TpContrat_N_Info':
                return "Tipo de contrato deve ser informado.";
                break;
            case 'TpInsc_Benef_N_Info':
                return "Tipo do beneficiário inválido.";
                break;
            case 'TpInsc_Benef_Invalid':
                return "Tipo do beneficiário inválido.";
                break;
            case 'TpInsc_Contrib_Invalid':
                return "Tipo de inscrição do contribuinte inválido.";
                break;
            case 'TpInsc_Estab_Invalid':
                return "Tipo de inscrição do Estabelecimento inválido.";
                break;
            case 'TpInsc_Estab_Invalid_TpLota':
                return "Tipo de inscrição do Estabelecimento inválido para o tipo de lotação.";
                break;
            case 'TpInsc_LocTrab_N_Info':
                return "Tipo de inscrição do local de trabalho deve ser informado.";
                break;
            case 'TpInterv_N_Info':
                return "Tipo de intervalo deve ser informado.";
                break;
            case 'TpJornad_N_Info':
                return "Tipo de jornada deve ser informado.";
                break;
            case 'TpLocal_N_Info':
                return "Tipo do local do acidente deve ser informado.";
                break;
            case 'TpLota_N_Info':
                return "Tipo de lotação deve ser informado.";
                break;
            case 'TpRegJor_N_Info':
                return "Tipo de regime de jornada deve ser informado.";
                break;
            case 'TpRegPrev_N_Info':
                return "Tipo de regime previdenciário deve ser informado.";
                break;
            case 'TpRegTrab_N_Info':
                return "Tipo de regime trabalhista deve ser informado.";
                break;
            case 'UnidSalar_N_Info':
                return "Unidade de pagamento do salário fixo deve ser informada.";
                break;
            case 'VlrDescon_N_Info':
                return "Valor dos descontos deve ser informado.";
                break;
            case 'VlrLiquid_N_Info':
                return "Valor Líquido deve ser informado.";
                break;
            case 'VlrProve_N_Info':
                return "Valor dos proventos deve ser informado.";
                break;
            case 'VlrSalar_N_Info':
                return "Valor do salário fixo deve ser informado.";
                break;
            default:
                return "Arquivo possui inconsistências.";
                break;
        }
    }

}