<?php
/**
 * GepSolicitacaoLogic.
 *
 * @package Logic
 * @author  tarcisiopereira <username@example.com>
 */
class GepSolicitacaoLogic{


    private $_GepSolicitacao;
    private $_GepCtrlencasoli;
    private $_GepSituacao;

    private $_GepLogalterasoli;
    private $_GepObservacaosoli;
    private $_GepTextosolifluxo;
    private $_GepFluxoencasoli;
    private $_GepFluxo;
    private $_GepCtrlencasoliLogic;
    private $_GepPerfilacessofluxo;
    private $_GepOperadorfluxo;

    /**
     * Construtor da classe.
     */
    public function __construct(){
        $this->_GepSolicitacao        = new GepSolicitacaoEntity();
        $this->_GepCtrlencasoliEntity = new GepCtrlencasoliEntity();
        $this->_GepSituacao           = new GepSituacaoEntity();
        $this->_GepLogalterasoli      = new GepLogalterasoliLogic();
        $this->_GepObservacaosoli     = new GepObservacaosoliLogic();
        $this->_GepTextosolifluxo     = new GepTextosolifluxoLogic();
        $this->_GepFluxoencasoli      = new GepFluxoencasoliLogic();
        $this->_GepFluxo              = new GepFluxoLogic();
        $this->_GepCtrlencasoliLogic  = new GepCtrlencasoliLogic();
        $this->_GepPerfilacessofluxo  = new GepPerfilacessofluxoEntity();
        $this->_GepOperadorfluxo      = new GepOperadorfluxoEntity();
    }


    /**       ok
     * Funcao que retorna o proximo numero de solicitacao.
     *
     * @param integer $nrorg    Numero da organizacao.
     * @param integer $stcodigo Codigo da tabela novocodigo.
     *
     * @return number
     */
    public static function retornaProxNumeroSolicitacao(
        $nrorg,
        $stcodigo
        )
    {
        $nrsolicitacao = (int)GepSolicitacaoEntity::retornaProxNumeroSoliserv(
            $nrorg,
            $stcodigo
        );
        return $nrsolicitacao;
    }


    /**     ok
     * Retorna dados da solicitacao.
     *
     * @param integer $nrorg       Numero da Organizacao.
     * @param integer $solicitacao Numero da Solicitacao.
     *
     * @return Ambigous <boolean, <type>, multitype:, mixed>
     */
    public function retornaDadosSoli($nrorg, $solicitacao){
        try {
            $dados = $this->_GepSolicitacao->retornaDadosSolicitacao($nrorg, $solicitacao);
            return $dados;
        } catch (Exception $e) {
            switch ($e->getCode()){
            case GepSolicitacaoEntity::SEM_REGISTRO:
                return GepSolicitacaoEntity::SEM_REGISTRO;
            default:
                tk_warning('Erro desconhecido: '.$e->getMessage());
                return false;
            }
        }
    }


    /**    ok
     * Atualiza tipo e situacao de uma solicitacao.
     *
     * @param integer $nrorg         Numero da Organziacao.
     * @param integer $filial        Codigo da filial.
     * @param integer $solicitacao   Numero da solicitacao que sera atualiada.
     * @param integer $tipo_soli     Tipo da solicitacao.
     * @param integer $situacao      Numero da Situacao.
     * @param integer $parceiro      Codigo do parceiro.
     * @param integer $grupo         Codigo do grupo.
     * @param string  $id_encerra    Identificador de encerramento da solicitacao.
     * @param integer $encerrado_por Codigo do parceiro que encerrou a solicitacao.
     * @param integer $encerrado_em  Data do encerramento.
     *
     * @return boolean
     */
    public function atualizaSolicitacao(
        $nrorg, $filial, $solicitacao, $tipo_soli, $situacao, $parceiro,
        $grupo, $id_encerra, $encerrado_por, $encerrado_em
    ){
        $atualizacao = $this->_GepSolicitacao->atualizaSolicitacao(
            $nrorg, $filial, $solicitacao, $tipo_soli, $situacao, $parceiro,
            $grupo, $id_encerra, $encerrado_por, $encerrado_em
        );
        return $atualizacao;
    }


    /**
     * Atualiza um campo de encerramento da solicita??o.
     *
     * @param integer $nrorg       N?mero da Organiza??o.
     * @param integer $filial      C?digo da filial.
     * @param integer $solicitacao N?mero da solicita??o.
     * @param integer $parceiro    Parceiro.
     * @param date    $data        Data de atualiza??o.
     *
     * @return boolean
     */
    public function atualizaEncerramentoSoli(
    $nrorg, $filial, $solicitacao, $parceiro, date $data
    ){
        $exclui_ctrl = $this->_GepCtrlencasoli->excluiControle($nrorg, $solicitacao);
        $atualizacao = $this->_GepSolicitacao->atualizaEncerramentoSoli(
            $nrorg, $filial, $solicitacao, $parceiro, $data
        );
        return $atualizacao;
    }


    /**
     * Gera novo codigo para o grupo de depend?ncias.
     *
     * @param integer $nrorg N?mero da Organiza??o.
     *
     * @return Ambigous <Ambigous, multitype:, boolean, multitype:>
     */
    public function novoCodigoDependencia($nrorg){
        $codigo = $this->_GepSolicitacao->ultimoCodigoDependencia($nrorg);
        $codigo++;
        return $codigo;
    }


    /**
     * Atualiza o campo de depend?ncia da solicitacao de uma organiza??o e filial.
     *
     * @param integer $nrorg       N?mero da Organiza??o.
     * @param integer $filial      C?digo da Filial.
     * @param integer $solicitacao N?mero da Solici??o.
     * @param integer $grupo       N?mero do grupo.
     * @param integer $operador    C?digo do Operador que atualiza a solicita??o.
     * @param integer $data        Data de altera??o.
     *
     * @return boolean
     */
    public function atualizaDependenciaSoli($nrorg, $filial, $solicitacao, $grupo, $operador, $data){
        try {
            $atualizacao = $this->_GepSolicitacao->atualizaDependenciaSoli(
                $nrorg, $filial, $solicitacao, $grupo, $operador, $data
            );
            return $atualizacao;
        } catch (Exception $e) {
            tk_warning($e->getMessage());
            return false;
        }
    }


    /**   ok
     * Retorna o SQL para a tabQuery de Dependencia entre as Solicitacoes.
     *
     * @param integer $nrorg Numero da Organizacao.
     * @param integer $grupo Numero do grupo de dependencia.
     *
     * @return string
     */
    public static function retornaSqlDependentes($nrorg, $grupo){
        $sql = GepSolicitacaoEntity::retornaSqlDependentes($nrorg, $grupo);
        return $sql;
    }


    /**         ok
     * Retorna dados de uma solicitacao por grupo.
     *
     * @param integer $nrorg  Numero da Organizacao.
     * @param integer $filial Codigo da Filial.
     * @param integer $grupo  Numero do Grupo.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public function retornaSolicitacaoPorGrupo($nrorg, $filial, $grupo){
        $dados = $this->_GepSolicitacao->retornaSolicitacaoPorGrupo($nrorg, $filial, $grupo);
        return $dados;
    }


    /**     ok
     * Retorna query para a tab de solicitacao.
     *
     * @param integer $nrorg    Numero da organizacao.
     * @param integer $filial   Codigo da filial.
     * @param integer $parceiro Codido do parceiro.
     *
     * @return string
     */
    public function retornaSqlTabSoli($nrorg, $filial, $parceiro, $entregasoli){
        /*if (empty($parceiro) === true)
            $parceiro = 'NULL';*/

        $tipofluxo = self::validaTipoFluxoPermissaoAcesso($nrorg, $parceiro);
        $sql = $this->_GepSolicitacao->retornaSqlTabSoli($nrorg, $filial, $parceiro, $entregasoli, $tipofluxo);
        return $sql;
    }


    /**     ok
     * Retorna o codigo do operador acionado da ultima solicitacao aberta pelo determinado operador.
     *
     * @param integer $nrorg    Numero da Organizacao.
     * @param integer $operador Codigo do Operador.
     *
     * @return Ambigous <Ambigous, multitype:, boolean, multitype:>
     */
    public function retornaParcAcionadoPorOperInclusao($nrorg, $operador){
        $dados = $this->_GepSolicitacao->retornaSoliPorOperInclusao($nrorg, $operador);
        if ($dados !== false) {
            return $dados->getNrparcoperacionado();
        }

        return null;
    }


    /**
     * Anexa arquivos, zipa e exclui original no caminho passado.
     *
     * @param string $dir_path Diret?rio a anexar arquivo.
     *
     * @return boolean
     */
    public function anexarArquivos($dir_path){
        try {
            // Cria diretorio.
            $dir = new TkFile($dir_path, false, TkFile::MODE_DIR);

            // Anexa arquivo.
            $file = TkFile::createFromUpload(
                null,
                $dir_path
            );

            // Limpa nome do arquivo - substitui espa?o, ponto e exclama??o por '_'.
            $procura = array(
                        " ",
                        '.',
                        '!',
                       );
            $file_name = $file->getName();
            $zip_name = str_replace($procura, '_', $file_name);

            $dir_path_zip = $file->getPath().DIRECTORY_SEPARATOR.$zip_name.'.zip';
            $zip = new TkFile($dir_path_zip);
            $zip->add($file);
            $zip->save();

            $file->destroy();

            return true;
        } catch (Exception $e) {
            tk_warning('Erro desconhecido: '.$e->getMessage());
            return false;
        }
    }


    /**        ok
     * Monta clausula de tab filter.
     *
     * @param integer $nrorg            Numero da Organizacao.
     * @param integer $solicitacao      Codigo da solicitacao.
     * @param integer $grupo_resp       Cogido do grupo responsavel.
     * @param integer $oper_resp        Cogido do operador responsavel.
     * @param integer $oper_acionado    Cogido do operador acionado.
     * @param string  $observacao       Texto da observacao do operador.
     * @param string  $observacao_geral Texto da observacao geral.
     * @param date    $data_inicial     Data de incluscao inicial.
     * @param date    $data_final       Data de incluscao final.
     * @param string  $encerramento     Codigo de encerramento.
     * @param integer $situacao         Codigo da situacao.
     *
     * @return string
     */
    public function filterSoli($nrorg, $solicitacao, $grupo_resp, $oper_resp, $oper_acionado, $observacao_operador,
                               $observacao_geral, $data_inicial, $data_final, $encerramento, $situacao,
                               $tipofluxo, $referencia, $idativo){
        $filter_conditions = array();
        $params = array();
        if (empty($solicitacao) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.NRSOLICITACAO = :NRSOLICITACAO";
            $params[":NRSOLICITACAO"] = $solicitacao;
        }

        if (empty($grupo_resp) !== true) {
            $filter_conditions[] = "(GEP_SOLICITACAO.NRPERFILACESSORESP IN (SELECT NRPERFILACESSO
                                                                            FROM PERFACESSPARC
                                                                           WHERE NRORG = :NRORG
                                                                             AND NRPERFILACESSO = :NRPERFILACESSO)
                                  OR GEP_SOLICITACAO.NRPERFILACESSORESP = :NRPERFILACESSORESP)";

            $params[":NRORG"] = $nrorg;
            $params[":NRPERFILACESSO"] = $grupo_resp;
            $params[":NRPERFILACESSORESP"] = $grupo_resp;
        }

        if (empty($oper_resp) !== true AND empty($oper_acionado) !== true) {
            $filter_conditions[] = "(GEP_SOLICITACAO.NRPARCOPERRESP     = :NRPARCOPERRESP
                                  OR GEP_SOLICITACAO.NRPARCOPERACIONADO = :NRPARCOPERACIONADO)";
            $params[":NRPARCOPERRESP"] = $oper_resp;
            $params[":NRPARCOPERACIONADO"] = $oper_acionado;

        } else if (empty($oper_resp) !== true) {
            $filter_conditions[] = "(GEP_SOLICITACAO.NRPARCOPERRESP  IN (SELECT NRPARCNEGOCIO
                                                                          FROM PERFACESSPARC
                                                                         WHERE NRORG = :NRORG
                                                                           AND NRPARCNEGOCIO = :NRPARCOPERRESP)
                                  OR GEP_SOLICITACAO.NRPARCOPERRESP = :NRPARCOPERRESP)";
            $params[":NRORG"] = $nrorg;
            $params[":NRPARCOPERRESP"] = $oper_resp;

        } else if (empty($oper_acionado) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.NRPARCOPERACIONADO = :NRPARCOPERACIONADO";
            $params[":NRPARCOPERACIONADO"] = $oper_acionado;
        }

        if (empty($observacao_operador) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.OBSERVACAO_OPERADOR like :OBSERVACAO_OPERADOR";
            $params[":OBSERVACAO_OPERADOR"] = "%{$observacao_operador}%";

        } else if (empty($observacao_geral) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.OBSERVACAO_GERAL like :OBSERVACAO_GERAL";
            $params[":OBSERVACAO_GERAL"] = "%{$observacao_geral}%";
        }

        if (empty($data_inicial) !== true) {
            $filter_conditions[] = "(GEP_SOLICITACAO.DTINCLUSAO > :DTINICIAL)";
            $params[":DTINICIAL"] = $data_inicial;

        }

        if (empty($data_final) !== true) {
            $filter_conditions[] = "(GEP_SOLICITACAO.DTINCLUSAO < :DTFINAL)";
            $params[":DTFINAL"] = $data_final;
        }

        if (empty($encerramento) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.IDSOLIENCERRADA = :IDSOLIENCERRADA";
            $params[":IDSOLIENCERRADA"] = $encerramento;
        }

        if (empty($situacao) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.NRSITUACAO = :NRSITUACAO";
            $params[":NRSITUACAO"] = $situacao;
        }

        if (empty($tipofluxo) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.NRTIPOFLUXO = :NRTIPOFLUXO";
            $params[":NRTIPOFLUXO"] = $tipofluxo;
        }

        if (empty($referencia) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.DSREFERENCIASOLI LIKE :DSREFERENCIASOLI";
            $params[":DSREFERENCIASOLI"] = "%{$referencia}%";
        }

        if (empty($idativo) !== true) {
            $filter_conditions[] = "GEP_SOLICITACAO.IDATIVO = :IDATIVO";
            $params["IDATIVO"] = $idativo;
        }

        $filter_conditions = implode(" AND ", $filter_conditions);
//        tk_warning($filter_conditions);
//        tk_var_dump($params);
        return array($filter_conditions, $params);
    }


    /**      ok
     * Retorna a query para a tab de atividades por solicitacao.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     *
     * @return string
     */
    public static function retornaSqlAtividadeSoli($nrorg, $solicitacao){
        $query = GepSolicitacaoEntity::retornaSqlAtividadeSoli($nrorg, $solicitacao);
        return $query;
    }


    /**    ok
     * Retorna um array com as solicitacoes dependentes entre si.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $solicitacao Numero da solicitacao.
     * @param integer $filial      Codigo da filial.
     *
     * @return Ambiguous|boolean
     */
    public function retornaSolicitacoesDependentes($nrorg, $grupo, $filial){
        $soli = $this->retornaSolicitacaoPorGrupo($nrorg, $filial, $grupo);
        if ($soli !== false) {
            $array_soli = array();

            foreach ($soli as $registros) {
                $array_soli[] = $registros->getNrsolicitacao();
            }

            return $array_soli;
        } else {
            return false;
        }
    }


    /**     ok
     * Salva solicitacoes dependentes.
     *
     * @param integer $nrorg       Numero da organizacao de alteracao.
     * @param integer $filial      Codigo da filial.
     * @param integer $operador    Operador de atualizacao.
     * @param date    $data        Data atual.
     * @param integer $solicitacao Codigo da solicitacao.
     * @param array   $array_soli  Array de solicitacoes que serao dependentes entre si.
     *
     * @return boolean
     */
    public function salvaDependencias(
        $nrorg, $filial, $operador, $data, $solicitacao, $array_soli
    ){
        $dados_soli = $this->retornaDadosSoli($nrorg, $solicitacao);
        if ($dados_soli->getNrgrupodependencia() === null OR $dados_soli->getNrgrupodependencia() === 0) {
            $grupo = $this->novoCodigoDependencia($nrorg);
        } else {
            $grupo = $dados_soli->getNrgrupodependencia();
        }

        foreach ($array_soli as $soli) {
            $this->_GepSolicitacao->atualizaDependenciaSoli(
                $nrorg, $filial, $soli, $grupo, $operador, $data
            );
        }

        return true;
    }


    /**     ok
     * Exclui dependencia entre solicitacoes.
     *
     * @param integer $nrorg       Numero da orgnizacao de alteracao.
     * @param integer $operador    Operador de alteracao.
     * @param date    $data        Data de alteracao.
     * @param integer $filial      Codifo da filial.
     * @param integer $solicitacao Codigo da solicitacao a perder dependencia.
     * @param integer $rows        Numero de linhas na tela.
     *
     * @return boolean
     */
    public function excluiDependencias($nrorg, $grupo, $solicitacao, $filial, $operador, $data){
        $num_linhas = $this->_GepSolicitacao->retornaNumDependentes($nrorg, $grupo);

        if ($num_linhas > 2) {
            $array_soli = array($solicitacao);
        } else {
            $array_soli = $this->retornaSolicitacoesDependentes($nrorg, $grupo, $filial);
        }

        $grupo = null;

        foreach($array_soli as $soli) {
            $this->_GepSolicitacao->atualizaDependenciaSoli($nrorg, $filial, $soli, $grupo, $operador, $data);
        }

        return true;
    }


    /**
     * Retona o proximo codigo a partir do max da tabela.
     *
     * @param integer $nrorg Numero da organizacao.
     *
     * @return Ambigous <boolean, multitype:>
     */
    public static function retornaProximoCodigoSoli($nrorg) {
        $codigo = GepSolicitacaoEntity::retornaProximoCodigoSoli($nrorg);
        return $codigo;
    }


    /**     ok
     * Retorna a query de solicitacoes disponiveis para dependencia.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $filial      Codigo da filial.
     * @param integer $fluxo       Tipo de Fluxo.
     * @param integer $solicitacao Codigo da solicitacao.
     *
     * @return string
     */
    public static function retornaQuerySoliDependentes($nrorg, $filial, $fluxo, $solicitacao){
        $query = GepSolicitacaoEntity::retornaQuerySoliDependentes($nrorg, $filial, $fluxo, $solicitacao);
        return $query;
    }


    public static function validaTipoFluxoPermissaoAcesso($nrorg, $parceiro){
        $tipos_de_fluxo = array();
        $dados_operador_acesso =  GepOperadorfluxoEntity::retornaOperadorTipoFluxo($nrorg, $parceiro);

        if (is_array($dados_operador_acesso)) {
            foreach($dados_operador_acesso as $obj){
                $tipos_de_fluxo[] = $obj->getNrtipofluxo();
            }
        }

        $perfisAcesso = Perfacessparc::consultaPerfacessparc($parceiro, $nrorg);
        foreach($perfisAcesso as $perfilacesso) {
            $dados_perfil_acesso = GepPerfilacessofluxoEntity::retornaPerfilAcessoTipoFluxo(
                $nrorg, $perfilacesso->getNrperfilacesso()
            );
            if (is_array($dados_perfil_acesso)) {
                foreach($dados_perfil_acesso as $obj){
                    $tipos_de_fluxo[] = $obj->getNrtipofluxo();
                }
            }
        }

        //Intersecao para tipos de fluxo repetido
        $tipos_de_fluxo = array_unique($tipos_de_fluxo);

        $tipos_de_fluxo = implode(',', $tipos_de_fluxo);

        if ($tipos_de_fluxo) return $tipos_de_fluxo; return 0;

    }


    /**     ok 3
     * Salva solicitacao.
     *
     * @param integer $nrorg       Numero da organizacao.
     * @param integer $filial      Codigo da filial.
     * @param integer $tpfluxo     Tipo de fluxo.
     * @param integer $solicitacao Codigo da solicitacao.
     *
     * @return string
     */
    public function salvaSolicitacao(
        $novo_registro, $solicitacao, $obs_geral, $obs_operador, $parceiro, $nrorg, $data, $operador, $tp_fluxo,
        $grupo, $tipo_soli, $texto_log, $log_before
    ) {
        if ($novo_registro === true) {
            if ($tp_fluxo !== '2') {
                // Insere os textos parametrizados.
                $textos = $this->_GepTextosolifluxo->insereTextosParametrizados(
                    $nrorg, $data, $operador, $tp_fluxo, $solicitacao
                );
            }

            // Insere o fluxo de encaminhamento inicial.
            $fluxoencasoli = $this->_GepFluxoencasoli->insereFluxoencasoli(
                $solicitacao, $parceiro, $grupo, null, null, $tipo_soli, null,
                null, ' ', $texto_log, $nrorg, $data, $operador
            );
        }

        // Gera log after.
        $this->_GepLogalterasoli->geraLogAfterSolicitacao($nrorg, $solicitacao, $operador, $data, $log_before);

        // Salva observacoes.
        $observacao = $this->_GepObservacaosoli->salvaObservacoes(
            $nrorg, $solicitacao, $parceiro, $obs_operador, $obs_geral, $data, $operador
        );

        return true;
    }


    public function executaTramitacao(
        $situacao_atual, $situacao, $tiposoli_atual, $solicitacao,
        $tx_troca, $parceiro, $perfil, $tx_confirma,
        $txt_obs, $resposta_fluxo, $nrorg, $data, $operador, $filial, $tp_fluxo
    ){
        if (empty($situacao) === true) {
            $tiposoli_ant = $novo_tiposoli = $tiposoli_atual;
            $nova_situacao = $situacao_atual;
            $situacao_ant = $situacao;

            $nrmotivo_fluxo = null;
            $txt_log = $tx_confirma;

            $insert_ctrl = $this->_GepCtrlencasoliLogic->insereControleSoli(
                $solicitacao, $novo_tiposoli, $nova_situacao,
                $tiposoli_atual, $situacao_atual,
                $nrorg, $data, $operador
            );

        } else {
            if ($resposta_fluxo === '9999999999') {
                $dados_controle = $this->_GepCtrlencasoliLogic->retornaDadosControle($nrorg, $solicitacao);
                if ($dados_controle === GepCtrlencasoliEntity::SEM_CTRL) {
                    $tiposoli_ant = $tiposoli_atual;
                    $situacao_ant = $situacao_atual;
                } else {
                    $tiposoli_ant = $dados_controle->getNrtiposoliante();
                    $situacao_ant = $dados_controle->getNrsituacaoante();
                }

                $novo_tiposoli = $tiposoli_atual;
                $nova_situacao = $situacao_atual;

                $nrmotivo_fluxo = null;
                $txt_log = $tx_troca;
            } else {
                $dados_fluxo = $this->_GepFluxo->retornaFluxo($nrorg, $resposta_fluxo);
                if ($dados_fluxo->getIdfluxo() === 'PROXIMA') {
                    $nova_situacao = $dados_fluxo->getNrsituacaoprox();
                    if ($nova_situacao === null) {
                        $nova_situacao = $situacao_atual;
                    }

                    $novo_tiposoli = $dados_fluxo->getNrtiposoliprox();
                    if ($novo_tiposoli === null) {
                        $novo_tiposoli = $tiposoli_atual;
                    }

                    $insert_ctrl = $this->_GepCtrlencasoliLogic->insereControleSoli(
                        $solicitacao, $novo_tiposoli, $nova_situacao,
                        $tiposoli_atual, $situacao_atual,
                        $nrorg, $data, $operador
                    );

                    $tiposoli_ant = $tiposoli_atual;
                    $situacao_ant = $situacao_atual;
                } else {
                    $dados_ctrl = $this->_GepCtrlencasoliLogic->retornaDadosControle($nrorg, $solicitacao);
                    if ($dados_ctrl === false OR $dados_ctrl === GepCtrlencasoliEntity::SEM_CTRL) {
                        $tiposoli_ant = null;
                        $situacao_ant = null;

                        $novo_tiposoli = $tiposoli_atual;
                        $nova_situacao = $situacao_atual;
                    } else {
                        $tiposoli_ant = $dados_ctrl->getNrtiposolicitacao();
                        $situacao_ant = $dados_ctrl->getNrsituacao();

                        $novo_tiposoli = $dados_ctrl->getNrtiposoliante();
                        $nova_situacao = $dados_ctrl->getNrsituacaoante();
                    }

                    $delete_ctrl = $this->_GepCtrlencasoliLogic->excluiControle($nrorg, $solicitacao);
                }

                $nrmotivo_fluxo = $dados_fluxo->getNrmotivofluxo();
                $txt_log = $dados_fluxo->getTxlogfluxo();
            }
        }

        $dados_situacao = $this->_GepSituacao->retornaSituacao($nrorg, $nova_situacao, $tp_fluxo);
        $id_encerra = $dados_situacao->getIdencerrasoli();

        //valida encerramento de solicitacao
        if ($id_encerra === 'N') {
            $this->_GepSolicitacao->atualizaSolicitacao(
                $nrorg, $filial, $solicitacao, $novo_tiposoli, $nova_situacao,
                $parceiro, $perfil, $id_encerra
            );

        } else {
            $this->_GepSolicitacao->atualizaSolicitacao(
                $nrorg, $filial, $solicitacao, $novo_tiposoli, $nova_situacao,
                $parceiro, $perfil, $id_encerra, $operador, $data
            );
        }

        $insere_log = $this->_GepFluxoencasoli->insereFluxoencasoli(
            $solicitacao, $parceiro, $perfil, $tiposoli_ant, $situacao_ant,
            $novo_tiposoli, $nova_situacao, $nrmotivo_fluxo, $txt_obs,
            $txt_log, $nrorg, $data, $operador
        );

        return true;
    }


}